#[non_exhaustive]pub enum JsonConfigError {
Config(ConfigError),
DoubleFraming {
framing: JsonFraming,
},
}Expand description
Construction errors.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Config(ConfigError)
The component section did not deserialize.
DoubleFraming
The source already frames one record per payload, but the deserializer is configured to frame the payload too (double-framing).
Fields

framing: JsonFramingThe offending deserializer framing.